"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchAuthorId = void 0;
const generated_1 = require("../../../graphql/generated");
const graphqlClient_1 = require("./client/graphqlClient");
async function fetchAuthorId({ accessToken, author, githubApiBaseUrlV4 = 'https://api.github.com/graphql', }) {
    if (author === null) {
        return null;
    }
    const query = (0, generated_1.graphql)(`
    query AuthorId($author: String!) {
      user(login: $author) {
        id
      }
    }
  `);
    const variables = { author };
    const client = (0, graphqlClient_1.getGraphQLClient)({ accessToken, githubApiBaseUrlV4 });
    const result = await client.query(query, variables);
    if (result.error) {
        throw new graphqlClient_1.GithubV4Exception(result);
    }
    return result.data?.user?.id;
}
exports.fetchAuthorId = fetchAuthorId;
//# sourceMappingURL=fetchAuthorId.js.map